@@ -44,7 +44,7 @@ n_eff <- function(n, rho) {
 #'
 #' @md
 #' 
-#' @description The approximate-profile likelihood estimator for the spatial autocorrelation parameter from a simultaneous autoregressive (SAR) model (Li et al. 2007). Note, the `APLE` approximation is quite unreliable when the number of observations is large.
+#' @description The approximate-profile likelihood estimator for the spatial autocorrelation parameter from a simultaneous autoregressive (SAR) model (Li et al. 2007). Note, the `APLE` approximation is not reliable when the number of observations is large.
 #' 
 #' @param x Numeric vector of values, length `n`. This will be standardized internally with \code{scale(x)}.
 #' @param w An `n x n` row-standardized spatial connectivity matrix. See \link[geostan]{shape2mat}.
@@ -54,7 +54,7 @@ n_eff <- function(n, rho) {
 #'
 #' @seealso \link[geostan]{mc}, \link[geostan]{moran_plot}, \link[geostan]{lisa}, \link[geostan]{sim_sar}
 #'
-#' @details To check reliability, the \code{APLE} can be compared to an estimate of the spatial autocorrelation parameter from an intercept-only SAR model.
+#' @details The \code{APLE} is an estimate of the spatial autocorrelation parameter one would obtain from fitting an intercept-only SAR model.
 #'
 #' @source
 #'
@@ -128,204 +128,6 @@ sim_sar <- function(m = 1, mu = rep(0, nrow(w)), w, rho, sigma = 1, ...) {
     return(x)
 }
 
-#' The Moran coefficient
-#'
-#' @description The Moran coefficient, a measure of spatial autocorrelation (also known as Global Moran's I)
-#' 
-#' @export
-#' 
-#' @param x Numeric vector of input values, length n.
-#' @param w An n x n spatial connectivity matrix. See \code{\link[geostan]{shape2mat}}. 
-#' @param digits Number of digits to round results to.
-#' @param warn If `FALSE`, no warning will be printed to inform you when observations with zero neighbors or `NA` values have been dropped. 
-#' @param na.rm If `na.rm = TRUE`, observations with `NA` values will be dropped from both `x` and `w`. 
-#' @return The Moran coefficient, a numeric value.
-#'
-#' @details If any observations with no neighbors are found (i.e. \code{any(Matrix::rowSums(w) == 0)}) they will be dropped automatically and a message will print stating how many were dropped.
-#'
-#' @seealso \link[geostan]{moran_plot}, \link[geostan]{lisa}, \link[geostan]{aple}
-#' 
-#' @examples
-#' library(sf)
-#' data(georgia)
-#' w <- shape2mat(georgia, style = "W")
-#' x <- georgia$ICE
-#' mc(x, w)
-#' @source
-#'
-#' Chun, Yongwan, and Daniel A. Griffith. Spatial statistics and geostatistics: theory and applications for geographic information science and technology. Sage, 2013.
-#' 
-#' Cliff, Andrew David, and J. Keith Ord. Spatial processes: models & applications. Taylor & Francis, 1981.
-#' 
-#' @importFrom Matrix rowSums
-#' 
-mc <- function(x, w, digits = 3, warn = TRUE, na.rm = FALSE) {
-    check_sa_data(x, w) 
-    na_idx <- which(is.na(x))   
-    if (na.rm == TRUE && length(na_idx) > 0) {   
-        if (warn) message(length(na_idx), " NA values found in x. They will be dropped from the data before calculating the Moran coefficient. If matrix w was row-standardized, it no longer is. To address this, you can use a binary connectivity matrix, using style = 'B' in shape2mat.")
-        x <- x[-na_idx]
-        w <- w[-na_idx, -na_idx]
-    }
-    if (any(Matrix::rowSums(w) == 0)) {
-        zero.idx <- which(Matrix::rowSums(w) == 0)
-        if (warn) message(length(zero.idx), " observations with no neighbors found. They will be dropped from the data before calculating the Moran coefficient. If matrix w was row-standardized, it no longer is. To address this, you can use a binary connectivity matrix, using style = 'B' in shape2mat.")
-        x <- x[-zero.idx]
-        w <- w[-zero.idx, -zero.idx]
-    }
-    xbar <- mean(x)
-    z <- x - xbar
-    ztilde <- as.numeric(w %*% z)
-    A <- sum(Matrix::rowSums(w))
-    n <- length(x)
-    mc <- as.numeric( n/A * (z %*% ztilde) / (z %*% z))
-    return(round(mc, digits = digits))
-}
-
-#' Moran plot
-#'
-#' @description Plots a set of values against their spatially lagged values and gives the Moran coefficient as a measure of spatial autocorrelation.
-#' 
-#' @export
-#' 
-#' @import ggplot2
-#' @param x A numeric vector of length n.
-#' @param w An n x n spatial connectivity matrix.
-#' @param xlab Label for the x-axis. 
-#' @param ylab Label for the y-axis.
-#' @param pch Symbol type.
-#' @param col Symbol color. 
-#' @param size Symbol size.
-#' @param alpha Symbol transparency.
-#' @param lwd Width of the regression line.
-#' @param na.rm If `na.rm = TRUE`, any observations of `x` with `NA` values will be dropped from `x` and from `w`.
-#' @details For details on the symbol parameters see the documentation for \link[ggplot2]{geom_point}.
-#'
-#' If any observations with no neighbors are found (i.e. \code{any(Matrix::rowSums(w) == 0)}) they will be dropped automatically and a message will print stating how many were dropped.
-#' 
-#' @return Returns a \code{gg} plot, a scatter plot with \code{x} on the horizontal and its spatially lagged values on the vertical axis (i.e. a Moran scatter plot).
-#'
-#' @seealso \link[geostan]{mc}, \link[geostan]{lisa}, \link[geostan]{aple}
-#'
-#' @source
-#'
-#' Anselin, Luc. "Local indicators of spatial association—LISA." Geographical analysis 27, no. 2 (1995): 93-115.
-#' 
-#' @examples
-#' data(georgia)
-#' x <- georgia$income
-#' w <- shape2mat(georgia, "W")
-#' moran_plot(x, w)
-#' @import ggplot2
-#' @importFrom signs signs
-#' @importFrom Matrix rowSums
-moran_plot <- function(x, w, xlab = "x (centered)", ylab = "Spatial Lag", pch = 20, col = "darkred", size = 2, alpha = 1, lwd = 0.5, na.rm = FALSE) {
-    check_sa_data(x, w)
-    na_idx <- which(is.na(x))
-    if (length(na_idx) > 0) {
-        if (na.rm == TRUE) {   
-            message(length(na_idx), " NA values found in x. They will be dropped from the data before creating the Moran plot. If matrix w was row-standardized, it no longer is. To address this, you can use a binary connectivity matrix, using style = 'B' in shape2mat.")
-            x <- x[-na_idx]
-            w <- w[-na_idx, -na_idx]
-        } else {
-            stop("NA values found in moran_plot(x, ...). Use moran_plot(x, na.rm = TRUE, ...)")
-        }
-    }
-    if (any(Matrix::rowSums(w) == 0)) {
-        zero.idx <- which(Matrix::rowSums(w) == 0)
-        message(length(zero.idx), " observations with no neighbors found. They will be dropped from the data before creating the Moran plot. If matrix w was row-standardized, it no longer is. To address this, you can use a binary connectivity matrix, using style = 'B' in shape2mat.")
-        x <- x[-zero.idx]
-        w <- w[-zero.idx, -zero.idx]
-    }
-    x <- x - mean(x)
-    xlag <- as.numeric(w %*% x)
-    sub <- paste0("MC = ", round(mc(x, w),3))
-    ggplot(data.frame(x = x,
-                      xlag = xlag),
-           aes(x = x, y = xlag)
-           ) +
-        geom_hline(yintercept = mean(xlag),
-                   lty = 3) +
-        geom_vline(xintercept = mean(x),
-                   lty = 3) +
-        geom_point(
-            pch = 20,
-            colour = col,
-            size = size,
-            alpha = alpha,
-            aes(x = x,
-                y = xlag)
-        ) +
-        geom_smooth(aes(x = x,
-                        y = xlag),
-                    method = "lm",
-                    formula = "y ~ x",
-                    lwd = lwd,
-                    col = "black",
-                    se = FALSE) +
-        scale_x_continuous(labels = signs::signs) +
-        scale_y_continuous(labels = signs::signs) +
-        labs(x = xlab,
-             y = ylab,
-             subtitle = sub) +
-        theme_classic()        
-}
-
-#' Local Moran's I
-#'
-#' @export
-#' @description A local indicator of spatial association (lisa).
-#'
-#' @param x Numeric vector of length `n`.
-#' @param w An `n x n` spatial connectivity matrix. See \link[geostan]{shape2mat}. If \code{w} is not row standardized (\code{all(Matrix::rowSums(w) == 1)}), it will automatically be row-standardized.
-#' @param type Return the type of association also (High-High, Low-Low, High-Low, and Low-High)? Defaults to \code{FALSE}.
-#'
-#' @details
-#'
-#' The values will be standardized with \code{z = scale(x)} first and \code{w} will be row-standardized if needed. The LISA values are the product of each \code{z} value with their respective mean surrounding value \code{lagz = w \%*\% z}; \code{lisa = z * lagz}. These are for exploratory analysis and model diagnostics. The function uses Equation 7 from Anselin (1995).
-#'
-#' An above-average value (i.e. positive z-value) with positive mean spatial lag indicates local positive spatial autocorrelation and is designated type "High-High"; a low value surrounded by high values indicates negative spatial autocorrelation and is designated type "Low-High", and so on.
-#' 
-#' @return If \code{type = FALSE} a numeric vector of lisa values for exploratory analysis of local spatial autocorrelation. If \code{type = TRUE}, a \code{data.frame} with columns \code{Li} (the lisa value) and \code{type}.
-#'
-#' @seealso \code{\link[geostan]{moran_plot}}, \code{\link[geostan]{mc}}, \code{\link[geostan]{aple}}
-#'
-#' @source
-#'
-#' Anselin, Luc. "Local indicators of spatial association—LISA." Geographical Analysis 27, no. 2 (1995): 93-115.
-#'
-#' @examples
-#' library(ggplot2)
-#' library(sf)
-#' data(georgia)
-#' w <- shape2mat(georgia, "W")
-#' x <- georgia$ICE
-#' li = lisa(x, w)
-#' head(li)
-#' ggplot(georgia, aes(fill = li$Li)) +
-#'   geom_sf() +
-#'   scale_fill_gradient2()
-#' @importFrom Matrix rowSums
-lisa <- function(x, w, type = TRUE) {
-    check_sa_data(x, w)
-    if (!all(round(Matrix::rowSums(w), 10) %in% c(0, 1))) w <- row_standardize(w)
-    z <- scale(x)
-    lag <- as.numeric(w %*% z)
-    zi <- as.numeric(z * lag)
-    if (any(Matrix::rowSums(w) == 0)) {
-        zero.idx <- which(Matrix::rowSums(w) == 0)
-        zi[zero.idx] <- NA        
-        message(length(zero.idx), " observations with no neighbors found. Their LISA values are being set to NA.")
-    }     
-    if (!type) return (zi)
-    type <- ifelse(z > 0 & lag > 0, "HH",
-         ifelse(z < 0 & lag > 0, "LH",
-         ifelse(z < 0 & lag < 0, "LL",
-         ifelse(z > 0 & lag < 0, "HL", NA
-                ))))
-    return (data.frame(Li = zi, type = type))
-}
-
 #' Spatial data diagnostics
 #'
 #' @description Visual diagnostics for areal data and model residuals
@@ -523,7 +325,7 @@ sp_diag.numeric <- function(y,
 #'
 #' @param binwidth A function with a single argument that will be passed to the `binwidth` argument in \code{\link[ggplot2]{geom_histogram}}. The default is to set the width of bins to `0.5 * sd(x)`.
 #' 
-#' @return A grid of spatial diagnostic plots for measurement error models comparing the raw observations to the posterior distribution of the true values. Includes a point-interval plot, a histogram of Moran coefficient values for the posterior distribution of Delta values (`Delta = z - x`, where `z` are the survey estimates and `x` are the modeled true values), and a map of the posterior mean of the Delta values. 
+#' @return A grid of spatial diagnostic plots for measurement error models comparing the raw observations to the posterior distribution of the true values. Includes a point-interval plot of raw values and modeled values; a Moran scatter plot for `delta = z - x` where `z` are the survey estimates and `x` are the modeled values; and a map of the delta values (take at their posterior means). 
 #'
 #' @seealso \code{\link[geostan]{sp_diag}}, \code{\link[geostan]{moran_plot}}, \code{\link[geostan]{mc}}, \code{\link[geostan]{aple}}
 #' 
@@ -765,9 +567,11 @@ make_EV <- function(C, nsa = FALSE, threshold = 0.2, values = FALSE) {
 #' 
 #' @source
 #'
-#' Griffith, D. A. (2012). Space, time, and space-time eigenvector filter specifications that account for autocorrelation. Estadística Espanola, 54(177), 7-34.
+#' Bivand, Roger S. and Pebesma, Edzer and Gomez-Rubio, Virgilio (2013). Applied spatial data analysis with R, Second edition. Springer, NY. https://asdar-book.org/
+#' 
+#' Griffith, Daniel A. (2012). Space, time, and space-time eigenvector filter specifications that account for autocorrelation. Estadística Espanola, 54(177), 7-34.
 #'
-#' Haining, R. P., & Li, G. (2020). Regression Modelling Wih Spatial and Spatial-Temporal Data: A Bayesian Approach. CRC Press.
+#' Haining, Robert P. and Li, Guangquan (2020). Regression Modelling Wih Spatial and Spatial-Temporal Data: A Bayesian Approach. CRC Press.
 #'
 #' @examples 
 #' data(georgia)
@@ -884,7 +688,7 @@ auto_gaussian <- function() {
     return(family)
 }
 
-#' WAIC
+#' Widely Applicable Information Criteria (WAIC)
 #'
 #' @description Widely Application Information Criteria (WAIC) for model comparison
 #' 
@@ -917,36 +721,6 @@ waic <- function(fit, pointwise = FALSE, digits = 2) {
   return(round(res, digits))
 }
 
-#' Expected value of the residual Moran coefficient.
-#'
-#' @description Expected value for the Moran coefficient of model residuals under the null hypothesis of no spatial autocorrelation.
-#' 
-#' @export
-#' 
-#' @param X model matrix, including column of ones.
-#' @param C Connectivity matrix.
-#' 
-#' @source
-#' 
-#'  Chun, Yongwan and Griffith, Daniel A. (2013). Spatial statistics and geostatistics. Sage, p. 18.
-#' 
-#' @return Returns a numeric value.
-#'
-#' @examples
-#' data(georgia)
-#' C <- shape2mat(georgia)
-#' X <- model.matrix(~ ICE + college, georgia)
-#' expected_mc(X, C)
-expected_mc <- function(X, C) {
-    C <- as.matrix(C)
-    n = nrow(X)
-    k = ncol(X)    
-    under <- (n-k) * sum(rowSums(C))
-    mc = -n * sum(diag( solve(t(X) %*% X) %*% t(X) %*% C %*% X )) / under
-    return(as.numeric(mc))
-}
-
-
 #' Edge list
 #'
 #' @description Creates a list of connected nodes following the graph representation of a spatial connectivity matrix.
@@ -1309,7 +1083,7 @@ get_shp <- function(url, folder = "shape") {
 #' @param se Data frame of standard errors; column names must match (exactly) the variable names used in the model formula. 
 #' @param bounds An optional numeric vector of length two providing the upper and lower bounds, respectively, of the variables. If not provided, they will be set to c(-Inf, Inf) (i.e., unbounded). Common usages include keeping percentages between zero and one hundred or proportions between zero and one.
 #' @param car_parts A list of data required for spatial CAR models, as created by \code{\link[geostan]{prep_car_data}}; optional. If omitted, the measurement error model will be a non-spatial Student's t model.
-#' @param prior A named list of prior distributions (see \code{\link[geostan]{priors}}). If none are provided, default priors will be assigned. The liste of priors may include the following parameters:
+#' @param prior A named list of prior distributions (see \code{\link[geostan]{priors}}). If none are provided, default priors will be assigned. The list of priors may include the following parameters:
 #' \describe{
 #'  \item{df}{If using a non-spatial ME model, the degrees of freedom (df) for the Student's t model is assigned a gamma prior with default parameters of `gamma(alpha = 3, beta = 0.2)`. Provide values for each covariate in `se`, listing the values in the same order as the columns of `se`.}
 #'
