@@ -51,6 +51,7 @@
 #' @param chains Number of MCMC chains to estimate. Default \code{chains = 4}.
 #' @param iter Number of samples per chain. Default \code{iter = 2000}.
 #' @param refresh Stan will print the progress of the sampler every \code{refresh} number of samples. Defaults to \code{500}; set \code{refresh=0} to silence this.
+#' @param keep_all  If `keep_all = TRUE` then samples for all parameters in the Stan model will be kept; this is necessary if you want to do model comparison with Bayes factors and the `bridgesampling` package.
 #' @param pars Optional; specify any additional parameters you'd like stored from the Stan model.
 #' @param control A named list of parameters to control the sampler's behavior. See \link[rstan]{stan} for details. 
 #' 
@@ -135,7 +136,7 @@
 #' p(y_j | data, model) = sum_{m=0}^censor_point Poisson( c_m | fitted_j),
 #' ```
 #' 
-#' For example, the US Centers for Disease Control and Prevention's CDC WONDER database censors all death counts between 0 and 9. To model CDC WONDER mortality data, you could provide `censor_point = 9` and then the likelihood statement for censored counts would equal the summation of the Poisson probability mass function over each integer ranging from zero through 9 (inclusive), conditional on the fitted values (i.e., all model paramters). See Donegan (2021) for additional discussion, references, and Stan code.
+#' For example, the US Centers for Disease Control and Prevention's CDC WONDER database censors all death counts between 0 and 9. To model CDC WONDER mortality data, you could provide `censor_point = 9` and then the likelihood statement for censored counts would equal the summation of the Poisson probability mass function over each integer ranging from zero through 9 (inclusive), conditional on the fitted values (i.e., all model parameters). See Donegan (2021) for additional discussion, references, and Stan code.
 #'
 #' 
 #' @return An object of class class \code{geostan_fit} (a list) containing: 
@@ -248,6 +249,7 @@ stan_esf <- function(formula,
                      censor_point,
                      prior_only = FALSE,
                      chains = 4, iter = 2e3, refresh = 500,
+                     keep_all = FALSE,
                      pars = NULL,
                      control = NULL,
                      ...) {
@@ -405,8 +407,13 @@ stan_esf <- function(formula,
         FRAME <- sys.nframe()
         inits <- init_fn_builder(FRAME_NUMBER = FRAME)
     }     
-    ## CALL STAN -------------    
-    samples <- rstan::sampling(stanmodels$foundation, data = standata, iter = iter, chains = chains, refresh = refresh, pars = pars, control = control, init = inits, ...)
+    ## CALL STAN -------------
+    if (keep_all == TRUE) {
+        xparsx <- NA
+    } else {
+        xparsx <- pars
+    }    
+    samples <- rstan::sampling(stanmodels$foundation, data = standata, iter = iter, chains = chains, refresh = refresh, pars = xparsx, control = control, init = inits, ...)
     ## OUTPUT -------------    
     out <- clean_results(samples, pars, is_student, has_re, Wx, xraw, me.list$x_me_idx)  
     out$data <- data.frame(as.matrix(ModData))
