@@ -49,6 +49,7 @@
 #' @param chains Number of MCMC chains to estimate. 
 #' @param iter Number of samples per chain. .
 #' @param refresh Stan will print the progress of the sampler every \code{refresh} number of samples; set \code{refresh=0} to silence this.
+#' @param keep_all  If `keep_all = TRUE` then samples for all parameters in the Stan model will be kept; this is necessary if you want to do model comparison with Bayes factors and the `bridgesampling` package.
 #' @param pars Optional; specify any additional parameters you'd like stored from the Stan model.
 #' @param control A named list of parameters to control the sampler's behavior. See \code{\link[rstan]{stan}} for details. 
 #' @param ... Other arguments passed to \link[rstan]{sampling}. For multi-core processing, you can use \code{cores = parallel::detectCores()}, or run \code{options(mc.cores = parallel::detectCores())} first.
@@ -303,6 +304,7 @@ stan_icar <- function(formula,
                       censor_point,
                       prior_only = FALSE,
                       chains = 4, iter = 2e3, refresh = 500,
+                      keep_all = FALSE,
                       pars = NULL,
                       control = NULL,
                       ...) {
@@ -449,8 +451,13 @@ stan_icar <- function(formula,
         FRAME <- sys.nframe()
         inits <- init_fn_builder(FRAME_NUMBER = FRAME)
     }     
-    ## CALL STAN -------------  
-    samples <- rstan::sampling(stanmodels$foundation, data = standata, iter = iter, chains = chains, refresh = refresh, pars = pars, control = control, init = inits, ...)
+    ## CALL STAN -------------
+    if (keep_all == TRUE) {
+        xparsx <- NA
+    } else {
+        xparsx <- pars
+    }    
+    samples <- rstan::sampling(stanmodels$foundation, data = standata, iter = iter, chains = chains, refresh = refresh, pars = xparsx, control = control, init = inits, ...)
     ## OUTPUT -------------        
     out <- clean_results(samples, pars, is_student, has_re, Wx, xraw, me.list$x_me_idx)
     out$data <- data.frame(as.matrix(ModData))
